package cn.com.ctop.kuaishou.modules.report.service.impl;

import cn.com.ctop.kuaishou.modules.report.entity.KuaishouReportDailyAccount;
import cn.com.ctop.kuaishou.modules.report.entity.KuaishouReportDailyAccountDTO;
import cn.com.ctop.kuaishou.modules.report.entity.KuaishouVideoInfoDTO;
import cn.com.ctop.kuaishou.modules.report.entity.ProjectAccountDTO;
import cn.com.ctop.kuaishou.modules.report.mapper.KuaishouReportDailyAccountMapper;
import cn.com.ctop.kuaishou.modules.report.service.IKuaishouReportDailyAccountService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.mgt.SecurityManager;
import org.jeecg.common.system.vo.LoginUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

@Service
public class KuaishouReportDailyAccountServiceImpl extends ServiceImpl<KuaishouReportDailyAccountMapper, KuaishouReportDailyAccount> implements IKuaishouReportDailyAccountService {

    @Autowired
    private KuaishouReportDailyAccountMapper dailyAccountMapper;

    @Override
    public List<JSONObject> selectCost(Long accountId, String startDate, String endDate) {
        return dailyAccountMapper.selectCost(accountId, startDate, endDate);
    }

    @Override
    public PageInfo<ProjectAccountDTO> getKuaishouProjectInfo(String startDate, String endDate, List<Long> projectList, Integer pageSize, Integer pageNum, String sort ){
        List<ProjectAccountDTO> projectAccountDTOList = new ArrayList<>();

        if(projectList==null || projectList.size()==0){
            LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
            //String userId = "a6abfea0f27843bf8595a234410afb04";
            String userId = sysUser.getId();
            String roleCode = dailyAccountMapper.getRoleCodeByUserId(userId);

            List<Long> mediaIds = new ArrayList<>();
            mediaIds.add(2L);
            mediaIds.add(4L);

            if("admin".equals(roleCode)){
                PageHelper.startPage(pageNum,pageSize);
                projectAccountDTOList = dailyAccountMapper.queryProjectMemberByAdmins(mediaIds);
            }else{
                PageHelper.startPage(pageNum,pageSize);
                projectAccountDTOList = dailyAccountMapper.queryProjectMemberByUserId(userId,mediaIds);
            }
        }else{
            PageHelper.startPage(pageNum,pageSize);
            projectAccountDTOList = dailyAccountMapper.queryProjectMemberByIds(projectList);
        }

        for(ProjectAccountDTO project:projectAccountDTOList){
            ProjectAccountDTO project2 = dailyAccountMapper.getKuaishouProjectInfo(startDate, endDate, project.getProjectId());
            project.setCharge(project2.getCharge());
            project.setPhotoShow(project2.getPhotoShow());
            project.setPhotoClick(project2.getPhotoClick());
            project.setAclick(project2.getAclick());
            project.setBclick(project2.getBclick());
            project.setActivation(project2.getActivation());
            project.setSubmit(project2.getSubmit());
            project.setEventRegister(project2.getEventRegister());
            project.setEventNextDayStay(project2.getEventNextDayStay());
            project.setActivationCost(project2.getActivationCost());
            project.setPhotoClickRate(project2.getPhotoClickRate());
            project.setBclickRate(project2.getBclickRate());
            project.setImpression1kCost(project2.getImpression1kCost());
            project.setPhotoClickCost(project2.getPhotoClickCost());
            project.setPhotoShare(project2.getPhotoShare());
            project.setActionCost(project2.getActionCost());
            project.setPhotoComment(project2.getPhotoComment());
            project.setPhotoLike(project2.getPhotoLike());
            project.setFollow(project2.getFollow());
            project.setReport(project2.getReport());
            project.setCancelFollow(project2.getCancelFollow());
            project.setBlock(project2.getBlock());
            project.setNagative(project2.getNagative());
            project.setDownloadStarted(project2.getDownloadStarted());
            project.setDownloadCompleted(project2.getDownloadCompleted());
            project.setEventNextDayStayCost(project2.getEventNextDayStayCost());
            project.setStatDate(startDate + "~" + endDate);
        }

        return new PageInfo<>(projectAccountDTOList);
    }

    @Override
    public PageInfo<ProjectAccountDTO> getKuaishouSaleProjectInfo(String startDate, String endDate, List<Long> projectList, Integer pageSize, Integer pageNum, String sort ){
        List<ProjectAccountDTO> projectAccountDTOList = new ArrayList<>();

        if(projectList==null || projectList.size()==0){
            LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();
            //String userId = "e9ca23d68d884d4ebb19d07889727dae";
            String userId = sysUser.getId();
            String roleCode = dailyAccountMapper.getRoleCodeByUserId(userId);

            List<Long> mediaIds = new ArrayList<>();
            mediaIds.add(2L);
            mediaIds.add(4L);

            if("admin".equals(roleCode)){
                PageHelper.startPage(pageNum,pageSize);
                projectAccountDTOList = dailyAccountMapper.queryProjectMemberByAdmins(mediaIds);
            }else{
                PageHelper.startPage(pageNum,pageSize);
                projectAccountDTOList = dailyAccountMapper.queryProjectInfoBySaleId(userId,mediaIds);
            }
        }else{
            PageHelper.startPage(pageNum,pageSize);
            projectAccountDTOList = dailyAccountMapper.queryProjectMemberByIds(projectList);
        }

        for(ProjectAccountDTO project:projectAccountDTOList){
            ProjectAccountDTO project2 = dailyAccountMapper.getKuaishouProjectInfo(startDate, endDate, project.getProjectId());
            project.setCharge(project2.getCharge());
            project.setPhotoShow(project2.getPhotoShow());
            project.setPhotoClick(project2.getPhotoClick());
            project.setAclick(project2.getAclick());
            project.setBclick(project2.getBclick());
            project.setActivation(project2.getActivation());
            project.setSubmit(project2.getSubmit());
            project.setEventRegister(project2.getEventRegister());
            project.setEventNextDayStay(project2.getEventNextDayStay());
            project.setActivationCost(project2.getActivationCost());
            project.setPhotoClickRate(project2.getPhotoClickRate());
            project.setBclickRate(project2.getBclickRate());
            project.setImpression1kCost(project2.getImpression1kCost());
            project.setPhotoClickCost(project2.getPhotoClickCost());
            project.setPhotoShare(project2.getPhotoShare());
            project.setActionCost(project2.getActionCost());
            project.setPhotoComment(project2.getPhotoComment());
            project.setPhotoLike(project2.getPhotoLike());
            project.setFollow(project2.getFollow());
            project.setReport(project2.getReport());
            project.setCancelFollow(project2.getCancelFollow());
            project.setBlock(project2.getBlock());
            project.setNagative(project2.getNagative());
            project.setDownloadStarted(project2.getDownloadStarted());
            project.setDownloadCompleted(project2.getDownloadCompleted());
            project.setEventNextDayStayCost(project2.getEventNextDayStayCost());
            project.setStatDate(startDate + "~" + endDate);
        }

        return new PageInfo<>(projectAccountDTOList);
    }


    @Override
    public PageInfo<KuaishouReportDailyAccountDTO> getKuaishouAccountInfoByProjectId(Long projectId, String startDate, String endDate, Integer pageSize, Integer pageNum){
        PageHelper.startPage(pageNum,pageSize);
        return new PageInfo<>(dailyAccountMapper.getKuaishouAccountInfoByProjectId(startDate, endDate, projectId));
    }

    @Override
    public PageInfo<KuaishouReportDailyAccountDTO> getKuaishouCampaignInfoByAccountId(Long accountId, String startDate, String endDate, Integer pageSize, Integer pageNum){
        PageHelper.startPage(pageNum,pageSize);
        return new PageInfo<>(dailyAccountMapper.getKuaishouCampaignInfoByAccountId(startDate, endDate, accountId));
    }

    @Override
    public PageInfo<KuaishouReportDailyAccountDTO> getKuaishouUnitInfoByCampaignId(Long campaignId, String startDate, String endDate, Integer pageSize, Integer pageNum){
        PageHelper.startPage(pageNum,pageSize);
        return new PageInfo<>(dailyAccountMapper.getKuaishouUnitInfoByCampaignId(startDate, endDate, campaignId));
    }

    @Override
    public PageInfo<KuaishouReportDailyAccountDTO> getKuaishouCreativeInfoByUnitId(Long unitId, String startDate, String endDate, Integer pageSize, Integer pageNum){
        PageHelper.startPage(pageNum,pageSize);
        List<KuaishouReportDailyAccountDTO> kuaishouCreativeInfoList = dailyAccountMapper.getKuaishouCreativeInfoByUnitId(startDate, endDate, unitId);
        //for(KuaishouReportDailyAccountDTO creativeInfo:kuaishouCreativeInfoList){
        //    KuaishouVideoInfoDTO videoInfo = dailyAccountMapper.getVideoUrl(creativeInfo.getPhotoId());
        //    creativeInfo.setUrl(videoInfo.getUrl());
        //    creativeInfo.setCoverUrl(videoInfo.getCoverUrl());
        //}
        return new PageInfo<>(kuaishouCreativeInfoList);
    }

}
